TopologicalSignatureDistance - LatentLego

Skip to content

# TopologicalSignatureDistance

### `latent.losses.TopologicalSignatureDistance`

Computes distance between topological signatures (Moor 2019).

#### `__init__(self, match_edges=None, eps=1e-08, return_additional_metrics=False, **kwargs)` `special`

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`match_edges` | `Literal['symmetric', 'random']` | One of the following: `'symmetric'` Match edged between signatures symmetrically `'random'` Match edged between signatures randomly `None` Don't match edges | `None`
`eps` | `float` | Positive float. Clipping value for numerical stability. | `1e-08`
`return_additional_metrics` | `bool` | Boolean, whether to return additional metrics. | `False`
`**kwargs` | `` | Other arguments passed to `keras.losses.Loss`. | `{}`